@@ -68,21 +68,20 @@ rforcecom.createBulkJob <-
                       '</jobInfo>')
     
     # Send request
-    h <- basicHeaderGatherer() 
-    t <- basicTextGatherer()
     endpointPath <- rforcecom.api.getBulkEndpoint(session['apiVersion'])
     URL <- paste(session['instanceURL'], endpointPath, '/job', sep="")
     OAuthString <- unname(session['sessionID'])
-    httpHeader <- c("X-SFDC-Session"=OAuthString, "Accept"="application/xml", 'Content-Type'="application/xml")
-    curlPerform(url=URL, httpheader=httpHeader, headerfunction = h$update, writefunction = t$update, ssl.verifypeer=F, postfields=xmlBody)
+    httpHeader <- httr::add_headers("X-SFDC-Session"=OAuthString, "Accept"="application/xml", 'Content-Type'="application/xml")
+    res <- httr::POST(url=URL, config=httpHeader, body=xmlBody)
+    res.content = httr::content(res, as='text', encoding='UTF-8')
     
     # BEGIN DEBUG
     if(exists("rforcecom.debug") && rforcecom.debug){ message(URL) }
-    if(exists("rforcecom.debug") && rforcecom.debug){ message(t$value()) }
+    if(exists("rforcecom.debug") && rforcecom.debug){ message(res.content) }
     # END DEBUG
     
     # Parse XML
-    x.root <- xmlRoot(xmlTreeParse(t$value(), asText=T))
+    x.root <- xmlRoot(xmlTreeParse(res.content, asText=T))
     
     # Check whether it success or not
     errorcode <- NA
