@@ -3,21 +3,20 @@ rforcecom.getObjectList <-
 function(session){
 
  # Send a query
- h <- basicHeaderGatherer()
- t <- basicTextGatherer()
  endpointPath <- rforcecom.api.getObjectListEndpoint(session['apiVersion'])
  URL <- paste(session['instanceURL'], endpointPath, sep="")
  OAuthString <- paste("Bearer", session['sessionID'])
- httpHeader <- c("Authorization"=OAuthString, "Accept"="application/xml", 'Content-Type'="application/xml")
- curlPerform(url=URL, httpheader=httpHeader, headerfunction = h$update, writefunction = t$update, ssl.verifypeer=F)
+ httpHeader <- httr::add_headers("Authorization"=OAuthString, "Accept"="application/xml", 'Content-Type'="application/xml")
+ res <- httr::GET(url=URL, config=httpHeader)
+ res.content = httr::content(res, as='text', encoding='UTF-8')
  
  # BEGIN DEBUG
  if(exists("rforcecom.debug") && rforcecom.debug){ message(URL) }
- if(exists("rforcecom.debug") && rforcecom.debug){ message(t$value()) }
+ if(exists("rforcecom.debug") && rforcecom.debug){ message(res.content) }
  # END DEBUG
  
  # Parse XML
- x.root <- xmlRoot(xmlTreeParse(t$value(), asText=T))
+ x.root <- xmlRoot(xmlTreeParse(res.content, asText=T))
  
  # Check whether it success or not
  errorcode <- NA
@@ -29,7 +28,7 @@ function(session){
  }
  
  # Parse XML
- xdf <- xmlToDataFrame(getNodeSet(xmlParse(t$value()),'//sobjects'))
+ xdf <- xmlToDataFrame(getNodeSet(xmlParse(res.content),'//sobjects'))
  return(xdf)
  
 }
