@@ -6,21 +6,20 @@ function(session, nextRecordsUrl){
  nextRecordsUrl <- sub("^/", "", nextRecordsUrl)
 
  # Retrieve XML via REST API
- h <- basicHeaderGatherer()
- t <- basicTextGatherer()
  endpointPath <- rforcecom.api.getSoqlEndpoint(session['apiVersion'])
  URL <- paste(session['instanceURL'], nextRecordsUrl, sep="")
  OAuthString <- paste("Bearer", session['sessionID'])
- httpHeader <- c("Authorization"=OAuthString, "Accept"="application/xml")
- curlPerform(url=URL, httpheader=httpHeader, headerfunction = h$update, writefunction = t$update, ssl.verifypeer=F)
+ httpHeader <- httr::add_headers("Authorization"=OAuthString, "Accept"="application/xml")
+ res <- httr::GET(url=URL, config=httpHeader)
+ res.content = httr::content(res, as='text', encoding='UTF-8')
  
  # BEGIN DEBUG
  if(exists("rforcecom.debug") && rforcecom.debug){ message(URL) }
- if(exists("rforcecom.debug") && rforcecom.debug){ message(t$value()) }
+ if(exists("rforcecom.debug") && rforcecom.debug){ message(res.content) }
  # END DEBUG
  
  # Parse XML
- x.root <- xmlRoot(xmlParse(t$value(), asText=T))
+ x.root <- xmlRoot(xmlParse(res.content, asText=T))
  
  # Check whether it success or not
  errorcode <- NA
